@@ -90,6 +90,60 @@ typedef enum _bool
 } BOOL;
 #endif
 
+    // First digit: 
+    // 0x80 of 0x00 makes LED not light up for representative mode. 
+    
+    // All digits:
+    // 0x0f = blank
+    // 0x0e = 'C' (2nd Digit = 'D') CD MODE LED
+    // 0x0d = 'P' (2nd Digit = '-') HD MODE LED
+    // 0x0c = '-' (2nd Digit = 'M') Invalid MODE
+    // 0x0b = 'A'                   AM MODE LED 
+    // 0x0a = 'F'                   FM MODE LED
+    // < 0x0a = Number.i
+
+typedef enum _radio_mode
+{
+    OFF_MODE = 0,
+    AM_RADIO,
+    FM_RADIO,
+    CD_MODE,
+    HD_MODE
+} RADIO_MODE;
+
+typedef enum _leds
+{
+    LED_NONE = 0x8f,
+    LED_AM = 0x0b,
+    LED_FM = 0x0a,
+    LED_CD = 0x0e,
+    LED_HD = 0x0d,
+} LED;
+
+
+// Writing to Reg 0x07 does nothing, 0x08 = PLAY LED, 0x09 = PAUSE LED.
+typedef enum _pp
+{
+    PP_NONE = 0x07,
+    PP_PLAY = 0x08,
+    PP_PAUSE = 0x09
+} PP;
+
+
+// Dots are in reg 0x06
+    // 0x00 = No Dots.
+    // 0x01 = middle dot
+    // 0x02 = bottom dot 
+    // 0x03 = both dots
+typedef enum _dots
+{
+    DOTS_NONE = 0,
+    DOTS_MIDDLE,
+    DOTS_BOTTOM,
+    DOTS_BOTH
+} DOTS;
+
+
 BOOL bI2CInitialised = FALSE;
 
 static struct option longopts[] = {
@@ -100,7 +154,7 @@ static struct option longopts[] = {
     { "update-temp", 0, 0, 'u' },
     { "volume",      0, 0, 'l' },
     { "manual",      0, 0, 'm' },
-    { "set-time",    0, 0, 's' },
+    { "time",        0, 0, 's' },
     { "version",     0, 0, 'v' },
     { "help",        0, 0, 'h' },
     { NULL,          0, 0,  0  }
@@ -116,18 +170,28 @@ void help(char *argv0)
 "  then there is a chance that you may destroy an EEPROM.\n"
 "\n"
 "  -i, --i2c <n>              Sets the I2C Bus (Compulsary)\n"
-"  -r, --radio [am fm off]    Set the radio to am, fm or off\n"
+"  -r, --radio [am | fm | off]  Set the radio to am, fm or off\n"
+"\n"
 "  -d, --display [\"xxxxxx\"]   Set the display to the numbers specified\n"
-"                             Available are: [0-9, A, F, M]\n"
-"                             Limited availability: [C, -, P, D] (try them :)\n"
+"                             Available are: [0-9, A, C, F, P]\n"
+"                             Limited availability: [M, D, -] (try them :)\n"
 "                             A Capital letter in digit[0] will also light up the mode led\n"
 "                             A small letter will suppress the led\n"
 "                             Anything else will be displayed as blank.\n"
+"                             Adding: [am | fm | cd | hd]\n"
+"                                     [play | pause]\n"
+"                                     [both | middle | bottom]\n"
+"                             will activate the relevant LED / dots.\n"
+"  e.g.\n"
+"  (1) -d 123456 will display 12 3456 \n"
+"  (2) -d \"123456 fm pause both\" will display 12 34:56 and also light up the fm and pause leds.\n"
+"  N.B. You cannot have multiple mode LEDs lit at the same time (e.g. am + fm, or play + pause).\n"
+"\n"
 "  -t, --temp                 Display the current temperature.\n"
 "  -u, --update-temp          Updates the temperature every 2 seconds.\n"
 "  -l, --volume               Displays any changes on the volume control.\n"
 "  -m, --manual               Allows you to interactively change a register.\n"
-"  -s, --set-time             Sets and displays the current local time.\n"
+"  -s, --time                 Sets and displays the current local time.\n"
 "\n"
 "  -v, --version              Print version\n"
 "  -h, --help                 This help\n"
@@ -137,15 +201,6 @@ void help(char *argv0)
   exit(1);
 }
 
-typedef enum _radio_mode
-{
-    OFF_MODE = 0,
-    AM_RADIO,
-    FM_RADIO,
-    CD_MODE,
-    HD_MODE
-} RADIO_MODE;
-
 int digimatrix_write_byte_data(int file, char reg, char data)
 {
     int res;
@@ -212,36 +267,29 @@ static void digimatrix_TurnOnRadio(int file, RADIO_MODE radio_mode)
     }
 }
 
-static void digimatrix_DisplayNumbers(int file, char digits[6])
+static void digimatrix_DisplayNumbers(int file, char digits[6], 
+                                      LED led, PP pp, DOTS dots)
 {
     int n;
     
-    digimatrix_write_byte_data(file, 0x23, 0x02); // Set to digit mode.
+    digimatrix_write_byte_data(file, 0x23, 0x02); // Set to digit mode (-- --:--).
     
-    // Large 2 Digits. 
-    // 0x80 of 0x00 makes LED not light up for representative mode. 
-    // 0x0f = blank
-    // 0x0e (in both) = CD (CD mode)
-    // 0x0d (in both) = P- (HD mode)
-    // 0x0c (in both) = -M (Invalid)
-    // 0x0b 0x0c = AM (AM mode)
-    // 0x0a 0x0c = FM (FM mode)
-    // < 0x0a = Number.
-   
-    // 0x01 = middle dot
-    // 0x02 = bottom dot 
-    // 0x03 = both dots
-    // 0x04 = no dots.
-    digimatrix_write_byte_data(file, 0x06, 0x04);
+    // Set up the Dots.
+    digimatrix_write_byte_data(file, 0x06, (unsigned char)dots);
 
-    //digimatrix_write_byte_data(file, 0x07, 0x01);
+    // Set the Play / Pause LEDs
+    digimatrix_write_byte_data(file, (unsigned char)pp, 0x01);
 
-    // Writing to this displays play
-    //digimatrix_write_byte_data(file, 0x08, 0x01);
+    // Now set the mode LEDs
+    // If a letter is used as the first digit next, the mode LED will be overridden. 
+    if (led != LED_NONE)
+    {
+        digimatrix_write_byte_data(file, 0x00, (unsigned char) led);
+    }
 
-    // Writing to this displays pause
-    //digimatrix_write_byte_data(file, 0x09, 0x01);
     
+
+    // Set the state of each digit.
     for (n=0; n<6; n++)
     {
         if (digits[n] <= '9' && digits[n] >= '0')
@@ -250,8 +298,6 @@ static void digimatrix_DisplayNumbers(int file, char digits[6])
         }
         else
         {
-            //if (n<2) // This does actually apply to all digits! 
-            {
                 switch (digits[n])
                 {
                 case 'a':
@@ -293,9 +339,9 @@ static void digimatrix_DisplayNumbers(int file, char digits[6])
                     digimatrix_write_byte_data(file, n, 0x0f);
                     break;
                 }
-            }
         }
     }
+    
 }
 
 static void digimatrix_DisplayTemp(int file, int temp)
@@ -513,10 +559,67 @@ int main(int argc, char *argv[])
             break;
             
         case 'd':
-            optarg[6] = 0x00;
-            printf("Setting display to: %s\n", optarg);
-            strncpy(digits, optarg, 6);
-            digimatrix_DisplayNumbers(file, digits);
+	    {
+	        LED led = LED_NONE;
+		PP pp = PP_NONE;
+		DOTS dots = DOTS_NONE;
+		
+                strncpy(digits, optarg, 6);
+                
+		printf("Args = %s", optarg);
+                printf("\nSetting display to: %s ", digits);
+    	        if (strstr(optarg, "play"))
+   	        {
+		    pp = PP_PLAY;
+		    printf(" play");
+                }
+    	        else if (strstr(optarg, "pause"))
+   	        {
+		    pp = PP_PAUSE;
+		    printf(" pause");
+                }
+		
+    	        if (strstr(optarg, "am"))
+   	        {
+		    led = LED_AM;
+		    printf(" am");
+                }
+    	        else if (strstr(optarg, "fm"))
+   	        {
+		    led = LED_FM;
+		    printf(" fm");
+                }
+    	        else if (strstr(optarg, "cd"))
+   	        {
+		    led = LED_CD;
+		    printf(" cd");
+                }
+    	        else if (strstr(optarg, "hd"))
+   	        {
+		    led = LED_HD;
+		    printf(" hd");
+                }
+
+
+    	        if (strstr(optarg, "both"))
+   	        {
+		    dots = DOTS_BOTH;
+		    printf(" :");
+                }
+    	        else if (strstr(optarg, "middle"))
+   	        {
+		    dots = DOTS_MIDDLE;
+		    printf(" -");
+                }
+    	        else if (strstr(optarg, "bottom"))
+   	        {
+		    dots = DOTS_BOTTOM;
+		    printf(" .");
+                }
+		printf("\n");
+		
+                digimatrix_DisplayNumbers(file, digits, led, pp, dots);
+	    }
             break;
             
         case 't':
